@@ -75,7 +75,7 @@
 #' @importFrom gridExtra grid.arrange arrangeGrob
 #' @importFrom gtable gtable_filter
 #' @importFrom grid textGrob unit unit.c gpar
-#' @importFrom variancePartition ggColorHue
+#' @importFrom scales hue_pal
 #' @export
 
 BarPlotCat <- function(probs, lims, extreme_probs = NULL, extreme_lims = NULL,
@@ -250,7 +250,7 @@ BarPlotCat <- function(probs, lims, extreme_probs = NULL, extreme_lims = NULL,
     colorObs <- "purple"
     colorLab <- c("blue", "darkorange3")
   } else if (color.set == "ggplot") {
-    colorFill <- ggColorHue(3)
+    colorFill <- hue_pal()(3)
     colorHatch <- c("indianred3", "deepskyblue3")
     colorMember <- c("#ffff7f")
     colorObs <- "purple"
@@ -336,6 +336,7 @@ BarPlotCat <- function(probs, lims, extreme_probs = NULL, extreme_lims = NULL,
       scale_fill_manual(name = legend_title,
                         values = colorFill, drop = F) +
       scale_y_continuous(expand = c(0, 0), limits = c(lims_pos, 100)) +  
+      coord_cartesian(clip = "off") +
       labs(x = panel_bottom_name[p], 
            y = "", 
            title = panel_title[p],
@@ -352,7 +353,7 @@ BarPlotCat <- function(probs, lims, extreme_probs = NULL, extreme_lims = NULL,
       # labels on top of color bars
       annotate("text", 
                x = x_vals,
-               y = tmp$probs[match(my_levels, tmp$cat)] + 2, 
+               y = pmin(tmp$probs[match(my_levels, tmp$cat)] + 2, 99.9),
                label = paste0(" ", round(tmp$probs[match(my_levels, tmp$cat)], 0), "% "), 
                color = "black", vjust = 0,
                size = 4.1) +
